RemoteConfigFetchStatus enum

Outcome of the most recent fetch attempt.

Inheritance
Available extensions

Values

noFetchYet → const RemoteConfigFetchStatus

No fetch has been attempted yet.

success → const RemoteConfigFetchStatus

The last fetch succeeded (including "not modified" responses).

failure → const RemoteConfigFetchStatus

The last fetch failed (network error, timeout, bad response, ...).

throttle → const RemoteConfigFetchStatus

The last fetch was rejected because of rate limiting.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RemoteConfigFetchStatus>
A constant List of the values in this enum, in order of their declaration.