SharedPreferencesConfigStorage class
The default ConfigStorage, backed by SharedPreferencesAsync.
- Implemented types
Constructors
-
Creates a storage using
preferences, or a newSharedPreferencesAsync.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String key) → Future< void> -
Removes
key.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → Future< String?> -
Returns the value stored under
key, ornullif absent.override -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → Future< void> -
Stores
valueunderkey, replacing any previous value.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited